==> lnl-2.1.10.tar.gz: lnl-2.1.10/src/item_prot.h <==
/* item.c */
void	init_item( void );
void	reset_item_town( void );
void	clr_dun_item( void );
item_kind_t	make_item( long x, long y, long dun_lev );
item_t	*make_item_sub( long dun_lev, bool_t flg_chest );
bool_t	make_item_wpn_rand( long dun_lev, item_t *item );
bool_t	make_item_wpn( long dun_lev, item_t *item, long n, bool_t curse );
bool_t	add_slayer( wpn_t *wpn, long dun_lev );
bool_t	make_item_armor_rand( long dun_lev, item_t *item );
bool_t	make_item_armor( long dun_lev, item_t *item, long n, bool_t curse );
bool_t	make_item_potion_rand( long dun_lev, item_t *item );
bool_t	make_item_potion( long dun_lev, item_t *item, long n );
bool_t	make_item_scroll_rand( long dun_lev, item_t *item );
bool_t	make_item_scroll( long dun_lev, item_t *item, long n );
bool_t	make_item_stick_rand( long dun_lev, item_t *item );
bool_t	make_item_stick( long dun_lev, item_t *item, long n );
bool_t	make_item_acce_rand( long dun_lev, item_t *item );
bool_t	make_item_acce( long dun_lev, item_t *item, long n );
bool_t	make_item_light_rand( long dun_lev, item_t *item );
bool_t	make_item_light( long dun_lev, item_t *item, long n );
bool_t	make_item_spike_rand( long dun_lev, item_t *item );
bool_t	make_item_spike( long dun_lev, item_t *item );
bool_t	make_item_food_rand( long dun_lev, item_t *item );
bool_t	make_item_food( long dun_lev, item_t *item, long n );
bool_t	make_item_chest_rand( long dun_lev, item_t *item );
bool_t	make_item_chest( long dun_lev, item_t *item, long contents_n );
bool_t	make_item_tobacco_rand( long dun_lev, item_t *item );
bool_t	make_item_tobacco( long dun_lev, item_t *item, long n );
bool_t	make_item_pipe_rand( long dun_lev, item_t *item );
bool_t	make_item_pipe( long dun_lev, item_t *item, long n );
bool_t	make_item_coin_rand( long dun_lev, item_t *item );
bool_t	make_item_coin( long dun_lev, item_t *item, long n );
bool_t	make_item_junk_rand( long dun_lev, item_t *item );
bool_t	make_item_junk( long dun_lev, item_t *item );
void	set_item_face( item_t *item );
void	set_item_name( item_t *item );
char	*get_str_can_use_item( mbr_t *mbr, item_t *item );
can_use_item_t	chk_can_use_item( mbr_t *mbr, item_t *item );
bool_t	identify_item( item_t *item );
bool_t	identify_potion( item_t *item );
bool_t	identify_scroll( item_t *item );
bool_t	identify_stick( item_t *item );
bool_t	identify_acce( item_t *item );
bool_t	send_item( mbr_t *mbr );
bool_t	receive_item( mbr_t *mbr );
bool_t	put_item( long x, long y, long max_r, item_t *item, bool_t flg_mbr );
bool_t	put_item_sub( long x, long y, item_t *item, long *np );
bool_t	put_item_in_chest( long x, long y, item_t *p );
bool_t	drop_item( long x, long y, item_t *item, long n );
bool_t	pick_up_item( mbr_t *mbr, long x, long y );
bool_t	give_mbr_item( mbr_t *mbr, item_t *item );
bool_t	equip_item_sel( mbr_t *mbr, item_t *item );
bool_t	equip_item( mbr_t *mbr, item_t *item, equip_kind_t kind );
bool_t	equip_item_sub( mbr_t *mbr, item_t *item, equip_kind_t kind );
bool_t	chk_singly_equip( item_t *item, equip_kind_t kind );
bool_t	chk_equip_two_handed_wpn(
	mbr_t *mbr, item_t *item, equip_kind_t kind
);
bool_t	chk_equip_kind( item_t *item, equip_kind_t kind );
bool_t	take_off_item( mbr_t *mbr, equip_kind_t kind );
bool_t	take_off_item_sub( mbr_t *mbr, equip_kind_t kind );
bool_t	break_item_fragile( item_t *item, bool_t flg_mbr );
void	break_item_contents( item_t *chest, mbr_t *mbr );
void	break_item( item_t *item, bool_t flg_mbr );
bool_t	open_item( item_t *item, mbr_t *mbr );
bool_t	open_item_pos( long x, long y, item_t *item, mbr_t *mbr );
bool_t	disarm_item( item_t *item );
void	chk_item_data( item_t *item );
void	chk_item_data_wpn( item_t *item );
void	chk_item_data_armor( item_t *item );
rate_t	calc_rate_abl_equip( mbr_t *mbr, abl_kind_t abl );
bool_t	teleport_item( item_t *item );
void	detect_item( long x, long y, long r );
bool_t	cmp_item( item_t *p1, item_t *p2 );
long	inc_item( item_t *item, long n );
void	inc_turn_all_item( void );
long	count_mbr_item_n( mbr_t *mbr );
bool_t	drop_arw( long x, long y, item_t *item );
void	dec_throw( mbr_t *mbr, bool_t flg_drop, long x, long y );
bool_t	chk_come_back_arw( mbr_t *mbr );
bool_t	reload_arw( mbr_t *mbr );
char	get_item_mjr( item_t *item );
char	get_item_mnr( item_t *item );
rate_t	get_slayer_rate( long dun_lev );
wpn_tab_t	*get_wpn_tab( wpn_kind_t kind );
wpn_tab_t	*get_wpn_tab_head( void );
armor_tab_t	*get_armor_tab( armor_kind_t kind );
armor_tab_t	*get_armor_tab_head( void );
potion_tab_t	*get_potion_tab( potion_kind_t kind );
potion_tab_t	*get_potion_tab_head( void );
scroll_tab_t	*get_scroll_tab( scroll_kind_t kind );
scroll_tab_t	*get_scroll_tab_head( void );
stick_tab_t	*get_stick_tab( stick_kind_t kind, spell_kind_t spell );
stick_tab_t	*get_stick_tab_head( void );
acce_tab_t	*get_acce_tab(
	ring_kind_t ring_kind,
	amulet_kind_t amulet_kind,
	necklace_kind_t necklace_kind
);
acce_tab_t	*get_acce_tab_head( void );
light_tab_t	*get_light_tab( light_kind_t kind );
light_tab_t	*get_light_tab_head( void );
food_tab_t	*get_food_tab( food_kind_t kind );
food_tab_t	*get_food_tab_head( void );
tobacco_tab_t	*get_tobacco_tab( tobacco_kind_t kind, tobacco_brand_t brand );
tobacco_tab_t	*get_tobacco_tab_head( void );
pipe_tab_t	*get_pipe_tab( pipe_kind_t kind );
pipe_tab_t	*get_pipe_tab_head( void );
coin_tab_t	*get_coin_tab( coin_kind_t kind );
coin_tab_t	*get_coin_tab_head( void );
long	get_wpn_tab_n( wpn_tab_t *p );
long	get_armor_tab_n( armor_tab_t *p );
long	get_potion_tab_n( potion_tab_t *p );
long	get_scroll_tab_n( scroll_tab_t *p );
long	get_stick_tab_n( stick_tab_t *p );
long	get_acce_tab_n( acce_tab_t *p );
long	get_light_tab_n( light_tab_t *p );
long	get_food_tab_n( food_tab_t *p );
long	get_tobacco_tab_n( tobacco_tab_t *p );
long	get_pipe_tab_n( pipe_tab_t *p );
long	get_coin_tab_n( coin_tab_t *p );
item_t	*get_item( long x, long y );
void	copy_item( item_t *dst, item_t *src );
void	del_item( item_t *p );
void	inc_chest_ref( item_t *chest );
void	dec_chest_ref( item_t *chest );
void	remove_mbr_del_item( long ls_mbr_n );
void	move_ls_item( item_t *dst, item_t *src );
item_t	*alloc_item( item_t *dmy );
void	free_item( item_t *p );
void	ins_ls_item( item_t *ls, item_t *p );
bool_t	ins_sort_item( item_t *ls, item_t *item );
bool_t	chk_ins_sort_item( item_t *ls, item_t *item, long max_n );
bool_t	chk_give_mbr_chest( mbr_t *mbr, item_t *item );
bool_t	chk_item_is_equip( item_t *p );
long	count_ls_item( item_t *ls, item_kind_t kind );
item_t	*get_item_free_next( void );
item_t	*get_mbr_item_asgn( mbr_t *mbr );
item_t	*get_mbr_item_asgn_equip( mbr_t *mbr );
item_t	*get_dun_item_asgn( void );
item_t	*get_shop_wpn_item_asgn( void );
item_t	*get_shop_armor_item_asgn( void );
item_t	*get_shop_magic_item_asgn( void );
item_t	*get_shop_temple_item_asgn( void );
item_t	*get_shop_grocery_item_asgn( void );
item_t	*get_shop_restaurant_item_asgn( void );
item_t	*get_shop_tearoom_item_asgn( void );
item_t	*get_shop_tobacco_item_asgn( void );
rate_t	get_resi_armor( mbr_t *p, resi_kind_t resi );
rate_t	add_hit( long n );
rate_t	add_wpn_crtcl( long n );
rate_t	add_dam( long n );
rate_t	add_def( long n );
rate_t	add_armor_crtcl( long n );
rate_t	add_ac( long n );
long	expr_wpn_add_hit( long lev );
long	expr_wpn_add_crtcl( long lev );
long	expr_wpn_add_dam( long lev );
long	expr_armor_add_ac( long lev );
long	expr_armor_add_def( long lev );
long	expr_armor_add_crtcl( long lev );
long	expr_light_turn( long max );
auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr );
char	*get_item_mjr_name( char mjr );
char	*get_item_mnr_name( char mjr, char mnr );
item_t	*get_item_mbr( long mbr, item_kind_t kind );
item_t	*get_item_nearest(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
item_t	*get_item_near(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
item_t	*get_item_disperse(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
item_t	*get_item_randm(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
item_t	*get_item_own(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
bool_t	chk_mark_item( item_t *p, act_kind_t act_kind );
bool_t	chk_own_item( item_t *item, mbr_t *mbr );
bool_t	chk_appoint_item( item_t *item, mbr_t *mbr );
long	get_chest_n( long dun_lev );

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/item_prot.h <==
/* item.c */
void	init_item( void );
void	reset_item_town( void );
void	clr_dun_item( void );
item_kind_t	make_item( long x, long y, long dun_lev );
item_t	*make_item_sub( long dun_lev, bool_t flg_chest );
item_t	*make_item_wpn_rand( long dun_lev );
item_t	*make_item_wpn( long dun_lev, long n, bool_t curse );
rate_t	get_slayer_rate( long dun_lev );
bool_t	add_slayer( wpn_t *wpn, long dun_lev );
item_t	*make_item_armor_rand( long dun_lev );
item_t	*make_item_armor( long dun_lev, long n, bool_t curse );
rate_t	get_armor_resi_rate( long dun_lev );
bool_t	add_armor_resi( item_t *p, long dun_lev, resi_kind_t resi );
resi_kind_t	get_armor_resi_kind( long dun_lev );
item_t	*make_item_potion_rand( long dun_lev );
item_t	*make_item_potion( long dun_lev, long n );
item_t	*make_item_scroll_rand( long dun_lev );
item_t	*make_item_scroll( long dun_lev, long n );
item_t	*make_item_stick_rand( long dun_lev );
item_t	*make_item_stick( long dun_lev, long n );
item_t	*make_item_acce_rand( long dun_lev );
item_t	*make_item_acce( long dun_lev, long n );
item_t	*make_item_light_rand( long dun_lev );
item_t	*make_item_light( long dun_lev, long n );
item_t	*make_item_spike_rand( long dun_lev );
item_t	*make_item_spike( long dun_lev );
item_t	*make_item_food_rand( long dun_lev );
item_t	*make_item_food( long dun_lev, long n );
item_t	*make_item_chest_rand( long dun_lev );
item_t	*make_item_chest( long dun_lev, long contents_n );
item_t	*make_item_tobacco_rand( long dun_lev );
item_t	*make_item_tobacco( long dun_lev, long n );
item_t	*make_item_pipe_rand( long dun_lev );
item_t	*make_item_pipe( long dun_lev, long n );
item_t	*make_item_disposal_rand( long dun_lev );
item_t	*make_item_disposal( long dun_lev );
item_t	*make_item_coin_rand( long dun_lev );
item_t	*make_item_coin( long dun_lev, long n );
item_t	*make_item_junk_rand( long dun_lev );
item_t	*make_item_junk( long dun_lev );
void	set_item_face( item_t *item );
void	set_item_name( item_t *item );
void	set_item_name_wpn( item_t *item );
void	set_item_name_armor( item_t *item );
void	set_item_name_potion( item_t *item );
void	set_item_name_scroll( item_t *item );
void	set_item_name_stick( item_t *item );
void	set_item_name_acce( item_t *item );
void	set_item_name_light( item_t *item );
void	set_item_name_spike( item_t *item );
void	set_item_name_food( item_t *item );
void	set_item_name_chest( item_t *item );
void	set_item_name_tobacco( item_t *item );
void	set_item_name_pipe( item_t *item );
void	set_item_name_disposal( item_t *item );
void	set_item_name_coin( item_t *item );
void	set_item_name_junk( item_t *item );
char	*get_str_can_use_item( mbr_t *mbr, item_t *item );
can_use_item_t	chk_can_use_item( mbr_t *mbr, item_t *item );
void	clean_all_disposal( mbr_t *mbr );
bool_t	identify_item( item_t *item );
bool_t	identify_potion( item_t *item );
bool_t	identify_scroll( item_t *item );
bool_t	identify_stick( item_t *item );
bool_t	identify_acce( item_t *item );
bool_t	send_item( mbr_t *mbr );
bool_t	receive_item( mbr_t *mbr );
bool_t	hand_item( chr_t *dst, chr_t *src, item_t *item, long n );
bool_t	put_item( long x, long y, long max_r, item_t *item, bool_t flg_mbr );
bool_t	put_item_sub( long x, long y, item_t *item, long *np );
bool_t	put_item_in_chest( long x, long y, item_t *p );
bool_t	drop_item( long x, long y, item_t *item, long n );
bool_t	pick_up_item( mbr_t *mbr, long x, long y );
bool_t	give_mbr_item( mbr_t *mbr, item_t *item, bool_t flg_force );
bool_t	give_mbr_item_sub( mbr_t *mbr, item_t *item );
bool_t	equip_item_sel( mbr_t *mbr, item_t *item );
bool_t	equip_item( mbr_t *mbr, item_t *item, equip_kind_t kind );
bool_t	equip_item_sub( mbr_t *mbr, item_t *item, equip_kind_t kind );
bool_t	chk_singly_equip( item_t *item, equip_kind_t kind );
bool_t	chk_equip_two_handed_wpn(
	mbr_t *mbr, item_t *item, equip_kind_t kind
);
bool_t	chk_equip_kind( item_t *item, equip_kind_t kind );
bool_t	take_off_item( mbr_t *mbr, equip_kind_t kind );
bool_t	take_off_item_sub( mbr_t *mbr, equip_kind_t kind );
bool_t	break_item_fragile( item_t *item, bool_t flg_mbr );
void	break_item_contents( item_t *chest, mbr_t *mbr );
void	break_item( item_t *item, bool_t flg_mbr );
bool_t	open_item( item_t *item, mbr_t *mbr );
bool_t	open_item_pos( long x, long y, item_t *item, mbr_t *mbr );
bool_t	disarm_item( item_t *item );
void	chk_item_data( item_t *item );
void	chk_item_data_wpn( item_t *item );
void	chk_item_data_armor( item_t *item );
rate_t	calc_rate_abl_equip( mbr_t *mbr, abl_kind_t abl );
bool_t	teleport_item( item_t *item );
void	detect_item( long x, long y, long r );
bool_t	cmp_item( item_t *p1, item_t *p2 );
long	inc_item( item_t *item, long n );
void	inc_turn_all_item( void );
long	count_mbr_item_n( mbr_t *mbr );
long	get_item_bundle( item_t *item );
bool_t	chk_throw_range( chr_t *chr );
bool_t	chk_throw_range_r( chr_t *chr, long r );
bool_t	drop_arw( long x, long y, item_t *item );
void	dec_throw( mbr_t *mbr, bool_t flg_drop, long x, long y );
bool_t	chk_come_back_arw( mbr_t *mbr );
bool_t	reload_arw( mbr_t *mbr );
char	get_item_mjr( item_t *item );
char	get_item_mnr( item_t *item );
wpn_tab_t	*get_wpn_tab( wpn_kind_t kind );
wpn_tab_t	*get_wpn_tab_head( void );
armor_tab_t	*get_armor_tab( armor_kind_t kind );
armor_tab_t	*get_armor_tab_head( void );
potion_tab_t	*get_potion_tab( potion_kind_t kind );
potion_tab_t	*get_potion_tab_head( void );
scroll_tab_t	*get_scroll_tab( scroll_kind_t kind );
scroll_tab_t	*get_scroll_tab_head( void );
stick_tab_t	*get_stick_tab( stick_kind_t kind, spell_kind_t spell );
stick_tab_t	*get_stick_tab_head( void );
acce_tab_t	*get_acce_tab(
	ring_kind_t ring_kind,
	amulet_kind_t amulet_kind,
	necklace_kind_t necklace_kind
);
acce_tab_t	*get_acce_tab_head( void );
light_tab_t	*get_light_tab( light_kind_t kind );
light_tab_t	*get_light_tab_head( void );
food_tab_t	*get_food_tab( food_kind_t kind );
food_tab_t	*get_food_tab_head( void );
tobacco_tab_t	*get_tobacco_tab( tobacco_kind_t kind, tobacco_brand_t brand );
tobacco_tab_t	*get_tobacco_tab_head( void );
pipe_tab_t	*get_pipe_tab( pipe_kind_t kind );
pipe_tab_t	*get_pipe_tab_head( void );
coin_tab_t	*get_coin_tab( coin_kind_t kind );
coin_tab_t	*get_coin_tab_head( void );
long	get_wpn_tab_n( wpn_tab_t *p );
long	get_armor_tab_n( armor_tab_t *p );
long	get_potion_tab_n( potion_tab_t *p );
long	get_scroll_tab_n( scroll_tab_t *p );
long	get_stick_tab_n( stick_tab_t *p );
long	get_acce_tab_n( acce_tab_t *p );
long	get_light_tab_n( light_tab_t *p );
long	get_food_tab_n( food_tab_t *p );
long	get_tobacco_tab_n( tobacco_tab_t *p );
long	get_pipe_tab_n( pipe_tab_t *p );
long	get_coin_tab_n( coin_tab_t *p );
item_t	*get_item( long x, long y );
void	copy_item( item_t *dst, item_t *src );
void	del_item( item_t *p );
void	inc_chest_ref( item_t *chest );
void	dec_chest_ref( item_t *chest );
void	remove_mbr_del_item( long ls_mbr_n );
void	move_ls_item( item_t *dst, item_t *src );
item_t	*alloc_item( void );
void	free_item( item_t *p );
void	ins_ls_item( item_t *ls, item_t *p );
bool_t	ins_sort_item( item_t *ls, item_t *item );
bool_t	chk_ins_sort_item( item_t *ls, item_t *item, long max_n );
bool_t	chk_give_mbr_chest( mbr_t *mbr, item_t *item );
bool_t	chk_item_is_equip( item_t *p );
long	count_ls_item( item_t *ls, item_kind_t kind );
item_t	*get_item_free_next( void );
item_t	*get_mbr_item_asgn( mbr_t *mbr );
item_t	*get_mbr_item_asgn_equip( mbr_t *mbr );
item_t	*get_dun_item_asgn( void );
item_t	*get_shop_bar_item_asgn( void );
item_t	*get_shop_wpn_item_asgn( void );
item_t	*get_shop_armor_item_asgn( void );
item_t	*get_shop_alchemy_item_asgn( void );
item_t	*get_shop_temple_item_asgn( void );
item_t	*get_shop_grocery_item_asgn( void );
item_t	*get_shop_restaurant_item_asgn( void );
item_t	*get_shop_tearoom_item_asgn( void );
item_t	*get_shop_tobacco_item_asgn( void );
rate_t	get_resi_armor( mbr_t *p, resi_kind_t resi );
bool_t	chk_wear_armor( chr_t *chr );
rate_t	add_hit( long n );
rate_t	add_wpn_crtcl( long n );
rate_t	add_dam( long n );
rate_t	add_def( long n );
rate_t	add_armor_crtcl( long n );
rate_t	add_ac( long n );
long	expr_wpn_add_hit( long lev );
long	expr_wpn_add_crtcl( long lev );
long	expr_wpn_add_dam( long lev );
long	expr_armor_add_def( long lev );
long	expr_armor_add_crtcl( long lev );
long	expr_armor_add_ac( long lev );
long	expr_light_turn( long max );
char	*get_item_mjr_name( char mjr );
char	*get_item_mnr_name( char mjr, char mnr );
item_t	*get_item_mbr( long mbr, item_kind_t kind );
item_t	*get_item_nearest(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
item_t	*get_item_near(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
item_t	*get_item_disperse(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
item_t	*get_item_randm(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
item_t	*get_item_own(
	mbr_t *mbr, act_kind_t act_kind, bool_t flg_auto_menu
);
bool_t	chk_mark_item( item_t *p, act_kind_t act_kind );
bool_t	chk_own_item( item_t *item, mbr_t *mbr );
bool_t	chk_appoint_item( item_t *item, mbr_t *mbr );
long	get_chest_n( long dun_lev );
